@@ -94,8 +94,10 @@ def _tsf_preprocess_data(data: pd.DataFrame):
     return tsf_data
 
 
-def calc_rolling_feature(ohlc: pd.DataFrame, win_len=10, selected_features=["linear_trend_timewise"],
-                         output_col_prefix=FEATURE_PREFIX, verbose=False):
+def calc_rolling_feature(ohlc: pd.DataFrame,
+                         win_len=10,
+                         selected_features=["linear_trend_timewise"],
+                         verbose=False, apply_col_name="Close"):
     """
         applies one feature on input data rolling wind
         Note: tsfresh feature result cant be pandas per window
@@ -104,7 +106,7 @@ def calc_rolling_feature(ohlc: pd.DataFrame, win_len=10, selected_features=["lin
         print("#######################")
         print("prepare data for tsfresh")
         print("#######################")
-    data = ohlc[["Close"]]
+    data = ohlc[[apply_col_name]]
     assert data.index.name == "Timestamp"
 
     tsf_data = _tsf_preprocess_data(data=data)
@@ -134,12 +136,12 @@ def calc_rolling_feature(ohlc: pd.DataFrame, win_len=10, selected_features=["lin
         selected_settings[key] = settings_comprehensive[key]
         selected_settings_cols = selected_settings_cols + get_feature_col_full_name(feature_name=key, win_len=win_len)
 
-    kind_to_fc_parameters = {"Close": selected_settings}
+    kind_to_fc_parameters = {apply_col_name: selected_settings}
 
     roll_features = extract_features(df_rolled,
                                      column_id="id",
                                      column_sort="sort",
-                                     column_value="Close",
+                                     column_value=apply_col_name,
                                      kind_to_fc_parameters=kind_to_fc_parameters,
                                      show_warnings=True
                                      )
