@@ -30,27 +30,6 @@ def test_create_operators():
     # assert
     assert len(result) == len(look_back_periods) * len(indicator_names)
 
-
-def test_apply_historical_return(ohlc_prices):
-    # arrange
-    periods = [3, 4]
-    magnifier_multiplier = 2
-    expected_operators = [ReturnsOperator.__name__]
-    original_ohlc = ohlc_prices.copy()
-
-    # act
-    result = apply_historical_return(ohlc_price=ohlc_prices,
-                                     periods=periods,
-                                     magnifier_multiplier=magnifier_multiplier)
-
-    # assert
-    assert_operators_results(operator_names=expected_operators,
-                             look_back_periods=periods,
-                             original_ohlc=original_ohlc,
-                             result=result,
-                             expected_columns=["Ind-Returns"])
-
-
 def test_apply_max_return_and_price(ohlc_prices):
     # arrange
     periods = [3, 4]
@@ -141,30 +120,6 @@ def test_apply_technical(ohlc_prices):
                              result=result,
                              expected_columns=["Rsi", "Willr"])
 
-
-def test_apply_lags(ohlc_prices):
-    # arrange
-    periods = [3, 4]
-    magnifier_multiplier = 2
-    lag_periods = [2]
-    return_period_for_lag = [3]
-
-    # act
-    _ = apply_historical_return(ohlc_price=ohlc_prices,
-                                periods=periods,
-                                magnifier_multiplier=magnifier_multiplier)
-
-    # act
-
-    lag_result = apply_lags(ohlc_price=ohlc_prices, lag_periods=lag_periods, ind_periods=return_period_for_lag)
-
-    # assert
-    result_cols = lag_result.columns
-    #
-    assert "Lag-Ind-Returns-3-T-0002" in result_cols
-    assert "Lag-Ind-Returns-3-T-0003" not in result_cols
-
-
 def assert_operators_results(operator_names, look_back_periods, original_ohlc, result, expected_columns):
     assert len(result.columns) == 4 + len(operator_names) * len(look_back_periods)
 
